/*****************************************************************************/
/* The contents of this file are subject to the Mozilla Public License       */
/* Version 1.1 (the "License"); you may not use this file except in          */
/* compliance with the License.  You may obtain a copy of the License at     */
/* http://www.mozilla.org/MPL/                                               */
/*                                                                           */
/* Software distributed under the License is distributed on an "AS IS"       */
/* basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the  */
/* License for the specific language governing rights and limitations under  */
/* the License.                                                              */
/*                                                                           */
/* The Original Code is the DSML Tools.                                      */
/*                                                                           */
/* The Initial Developer of the Original Code is Data Connection Limited.    */
/* Portions created by Data Connection are Copyright (C) 2000 Data           */
/* Connection Limited.  All Rights Reserved.                                 */
/*                                                                           */
/* Contributor(s):                                                           */
/*                                                                           */
/* Alternatively, the contents of this file may be used under the terms of   */
/* the GNU General Public License Version 2 or later (the "GPL"), in which   */
/* case the provisions of the GPL are applicable instead of those above.  If */
/* you wish to allow use of your version of this file only under the terms   */
/* of the GPL and not to allow others to use your version of this file under */
/* the MPL, indicate your decision by deleting the provisions above and      */
/* replace them with the notice and other provisions required by the GPL.    */
/* If you do not delete the provisions above, a recipient may use your       */
/* version of this file under either the MPL or the GPL.                     */
/*                                                                           */
/* The Original Code was written to the Glory of God, for Data Connection,   */
/* by Gervase Markham <gerv@dsmltools.org>                                   */
/*****************************************************************************/
package org.dsmltools;

import netscape.ldap.*;
import netscape.ldap.util.*;
import java.util.*;
import org.w3c.dom.*;
import org.apache.xerces.dom.*;

/** 

  This class manages the connection to an LDAP server.  It is a superclass
  of DSMLLDAPReader and DSMLLDAPWriter.
  */
public class DSMLLDAPConnection
{
/** 

  The object which controls the LDAP connection
  */
  protected LDAPConnection m_conn = null;

/** This function connects to an LDAP database

  @param xiHostname The name of the host to connect to
  @param xiPort The port to connect on
  @param xiUsername The directory entry DN to use as the username
  @param xiPassword The password to give
  */
  public void connect(String xiHostname, 
                      int    xiPort, 
                      String xiUsername, 
                      String xiPassword)
  {
    /*************************************************************************/
    /* Disconnect if we are connected                                        */
    /*************************************************************************/
    if (m_conn != null)
    {
      disconnect();
    }

    m_conn = new LDAPConnection();

    /*************************************************************************/
    /* GRM - 2000-01-24                                                      */
    /* Use LDAP v3 protocol for all communications                           */
    /*************************************************************************/
    Integer lVersion = new Integer(3);

    try
    {
      m_conn.setOption(LDAPv2.PROTOCOL_VERSION, lVersion);
    }
    catch (LDAPException lExcept)
    {
      System.err.println("Unable to set connection to use LDAP version 3.");
    }

    /*************************************************************************/
    /* Connect to the database                                               */
    /*************************************************************************/
    try 
    {
      m_conn.connect(xiHostname, xiPort, xiUsername, xiPassword);
    } 
    catch (LDAPException lExcept) 
    {
      switch(lExcept.getLDAPResultCode()) 
      {
        case LDAPException.NO_SUCH_OBJECT:
          System.err.println("Server: The specified user does not exist.");
          break;

        case LDAPException.INVALID_CREDENTIALS:
          System.err.println("Server: Invalid username or password.");
          break;    

        default:
          System.err.println("LDAPException during connect: " + 
                             lExcept.toString());
          break;
      }
        
      m_conn = null;
    }
  
    /*************************************************************************/
    /* Print an appropriate message                                          */
    /*************************************************************************/
    if (m_conn != null)
    {
      System.err.println("Connected to " + xiHostname + ":" + xiPort);
    }
    else
    {
      System.err.println("Failed to connect to " + xiHostname + ":" + xiPort);
      System.exit(1);
    }

  } /* connect() */

  /***************************************************************************/
  /* Method: disconnect()                                                    */
  /*                                                                         */
  /* This functions disconnects from the current LDAP server, if there is    */
  /* one.                                                                    */
  /***************************************************************************/
  public void disconnect()
  {
    if (m_conn != null)
    {
      try 
      {
        m_conn.disconnect();

        m_conn = null;
      }
      catch (LDAPException lExcept)
      {
        System.err.println("LDAPException disconnecting from previous host: " + 
                           lExcept.toString());
      }
    }
    else
    {
    }

  } /* disconnect() */
                                                                            
} /* DSMLLDAPConnection */
