/*****************************************************************************/
/* The contents of this file are subject to the Mozilla Public License       */
/* Version 1.1 (the "License"); you may not use this file except in          */
/* compliance with the License.  You may obtain a copy of the License at     */
/* http://www.mozilla.org/MPL/                                               */
/*                                                                           */
/* Software distributed under the License is distributed on an "AS IS"       */
/* basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the  */
/* License for the specific language governing rights and limitations under  */
/* the License.                                                              */
/*                                                                           */
/* The Original Code is the DSML Tools.                                      */
/*                                                                           */
/* The Initial Developer of the Original Code is Data Connection Limited.    */
/* Portions created by Data Connection are Copyright (C) 2000 Data           */
/* Connection Limited.  All Rights Reserved.                                 */
/*                                                                           */
/* Contributor(s):                                                           */
/*                                                                           */
/* Alternatively, the contents of this file may be used under the terms of   */
/* the GNU General Public License Version 2 or later (the "GPL"), in which   */
/* case the provisions of the GPL are applicable instead of those above.  If */
/* you wish to allow use of your version of this file only under the terms   */
/* of the GPL and not to allow others to use your version of this file under */
/* the MPL, indicate your decision by deleting the provisions above and      */
/* replace them with the notice and other provisions required by the GPL.    */
/* If you do not delete the provisions above, a recipient may use your       */
/* version of this file under either the MPL or the GPL.                     */
/*                                                                           */
/* The Original Code was written to the Glory of God, for Data Connection,   */
/* by Gervase Markham <gerv@dsmltools.org>                                   */
/*****************************************************************************/
package org.dsmltools.util;

import java.util.Comparator;
import netscape.ldap.LDAPEntry;

/** 

  This class implements the Comparator interface for comparing LDAPEntry
  objects on the basis of length of DN.
  */
public class DNLengthComparator implements Comparator
{
/** 

  True if we sort smallest first, false for biggest first.
  */
  private boolean m_smallestFirst = true;

/** Defines which way we are sorting.

  @param xiSmallestFirst Whether we sort smallest first or largest first.
  */
  public DNLengthComparator(boolean xiSmallestFirst)
  {
    m_smallestFirst = xiSmallestFirst;

  } /* DNLengthComparator() */

/** This method compares two Objects (which should be LDAPEntry objects)
    and returns -1, 0 or 1 depending on the relative length of their DNs.

  @param xiO1 The first object
  @param xiO2 The second object

  @return 0, 1 or -1 depending on relative DN length
  */
  public int compare(Object xiO1, Object xiO2)
  {
    int lRetVal;

    /*************************************************************************/
    /* Convert to LDAPEntries                                                */
    /*************************************************************************/
    LDAPEntry lEntry1 = (LDAPEntry)xiO1;
    LDAPEntry lEntry2 = (LDAPEntry)xiO2;

    /*************************************************************************/
    /* Get DN length                                                         */
    /*************************************************************************/
    int lLength1 = (lEntry1.getDN()).length();
    int lLength2 = (lEntry2.getDN()).length();

    /*************************************************************************/
    /* Compare lengths                                                       */
    /*************************************************************************/
    if (lLength1 < lLength2)
    {
      if (m_smallestFirst)
      {
        lRetVal = -1;
      }
      else
      {
        lRetVal = +1;
      }
    }
    else if (lLength1 > lLength2)
    {
      if (m_smallestFirst)
      {
        lRetVal = +1;
      }
      else
      {
        lRetVal = -1;
      }
    }
    else
    {
      lRetVal = 0;
    }

    return lRetVal;

  } /* compare() */

/** This method uses compare() to return a boolean if the LDAPEntries have
    DNs of equal length.

  @param xiO1 The first object
  @param xiO2 The second object

  @return True if DNs have equal length, false otherwise.
  */
  public boolean equals(Object xiO1, Object xiO2)
  {
    boolean lRetVal = (compare(xiO1, xiO2) == 0);
    return lRetVal;

  } /* equals() */

} /* DNLengthComparator */
