/*****************************************************************************/
/* The contents of this file are subject to the Mozilla Public License       */
/* Version 1.1 (the "License"); you may not use this file except in          */
/* compliance with the License.  You may obtain a copy of the License at     */
/* http://www.mozilla.org/MPL/                                               */
/*                                                                           */
/* Software distributed under the License is distributed on an "AS IS"       */
/* basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the  */
/* License for the specific language governing rights and limitations under  */
/* the License.                                                              */
/*                                                                           */
/* The Original Code is the DSML Tools.                                      */
/*                                                                           */
/* The Initial Developer of the Original Code is Data Connection Limited.    */
/* Portions created by Data Connection are Copyright (C) 2000 Data           */
/* Connection Limited.  All Rights Reserved.                                 */
/*                                                                           */
/* Contributor(s):                                                           */
/*                                                                           */
/* Alternatively, the contents of this file may be used under the terms of   */
/* the GNU General Public License Version 2 or later (the "GPL"), in which   */
/* case the provisions of the GPL are applicable instead of those above.  If */
/* you wish to allow use of your version of this file only under the terms   */
/* of the GPL and not to allow others to use your version of this file under */
/* the MPL, indicate your decision by deleting the provisions above and      */
/* replace them with the notice and other provisions required by the GPL.    */
/* If you do not delete the provisions above, a recipient may use your       */
/* version of this file under either the MPL or the GPL.                     */
/*                                                                           */
/* The Original Code was written to the Glory of God, for Data Connection,   */
/* by Gervase Markham <gerv@dsmltools.org>                                   */
/*****************************************************************************/
package org.dsmltools.util;

import org.w3c.dom.Node;
import org.apache.xerces.dom.TextImpl;
import org.w3c.dom.traversal.NodeFilter;

/** 

  This class is an implementation of the NodeFilter interface which passes
  only text nodes that contain only whitespace.  We use it on all DSML
  documents we read in, as part of the workaround for the problem that the
  parser won't remove them automatically for us.
  */
public class WhitespaceFilter implements NodeFilter
{
/** This method determines whether a node is a whitespace text node or not.

  @param xiNode The node to check

  @return Either FILTER_REJECT or FILTER_ACCEPT, depending on whether
  @return node contains only whitespace or not.
  */
  public short acceptNode(Node xiNode)
  {
    short lRetVal = FILTER_REJECT;

    if (xiNode.getNodeType() == Node.TEXT_NODE)
    {
      if (((xiNode.getNodeValue()).trim()).equals(""))
      {
        /*********************************************************************/
        /* No trace because this function gets called a myriad number of     */
        /* times, and it's very simple                                       */
        /*********************************************************************/
        lRetVal = FILTER_ACCEPT;
      }
    }

    return lRetVal;
  
  } /* acceptNode() */

} /* WhitespaceFilter */
